% For use with Matlab
% Copyright (C) 2020 -- Jerome Mendes <jermendes@gmail.com> or <jermendes@isr.uc.pt>, Rui Araujo <rui@isr.uc.pt>
% Jerome Mendes, Ricardo Maia, Rui Araujo, and  Francisco A.A. Souza. "Self-Evolving Fuzzy Controller Composed of Univariate Fuzzy Control". Applied Sicences, 2020.
% The "uSelf-FLC toolbox" comes with ABSOLUTELY NO WARRANTY;
% In case of publication of any application of this method, please, cite the work:
% Jerome Mendes, Ricardo Maia, Rui Araujo, and  Francisco A.A. Souza.
% Self-Evolving Fuzzy Controller Composed of Univariate Fuzzy Control Rules.
% Applied Sciences, 2020, 10(17), 5836.
% DOI: https://doi.org/10.3390/app10175836
% http://www.isr.uc.pt/~jermendes/    ;     http://www.isr.uc.pt/~rui/

function [] = PlotMFs(x, resolution)
%% Description
% This function presents the plots of the membership functions of all input variables
%% Function inputs
% x - Struct with all parameters of the neo-fuzzy
% resolution - resolution of MFs plot

if ~exist('resolution')
    % if resolution does not exist
    resolution = 10000;
end

n_var = length( x ); % number of variables

k = 1;

for j=1:n_var
    
    figure
    
    n_MFs = size( x(j).Rules,1); % number of MFs for variable j
    
    universe = x(j).Limit(1) : ceil( abs(x(j).Limit(2))+abs(x(j).Limit(1))) /resolution : x(j).Limit(2); % x axis
    
    MF(k,:) = universe;
    
    k = k + 1;
    
    for i = 1:n_MFs % for each rule of variable j
        
        parameters(1,1) = x(j).Rules(i,1); % parameter a_{j,i};
        parameters(1,2) = x(j).Rules(i,2); % parameter b_{j,i};
        parameters(1,3) = x(j).Rules(i,3); % parameter c_{j,i};
        
        y = trimf(universe, parameters); % Triangular membership function values
        
        MF(k,:) = y;
        k = k + 1;
        
        plot(universe,y); % plot of the membership function
        hold on;
        labels{i} = strcat('MF ', num2str(i)); % Save legend
        
    end
    
    legend(labels) % Figure legends
    
    title(sprintf('MFs of input variable x_{%d}', j)) % Figure title
    
end


end
